@@ -3,7 +3,7 @@ package Crypt::JWT;
 use strict;
 use warnings;
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 use Exporter 'import';
 our %EXPORT_TAGS = ( all => [qw(decode_jwt encode_jwt)] );
@@ -653,9 +653,9 @@ Named arguments:
 
 =over
 
-=item * token (mandatory)
+=item * token
 
-A string with either JWS or JWE JSON Web Token.
+Mandatory argument, a string with either JWS or JWE JSON Web Token.
 
  ### JWS token example (3 segments)
  $t="eyJhbGciOiJIUzI1NiJ9.dGVzdA.ujBihtLSr66CEWqN74SpLUkv28lra_CeHnxLmLNp4Jo";
@@ -663,7 +663,7 @@ A string with either JWS or JWE JSON Web Token.
  ### JWE token example (5 segments)
  $t="eyJlbmMiOiJBMTI4R0NNIiwiYWxnIjoiQTEyOEtXIn0.UusxEbzhGkORxTRq0xkFKhvzPrXb9smw.VGfOuq0Fxt6TsdqLZUpnxw.JajIQQ.pkKZ7MHS0XjyGmRsqgom6w";
 
-=item * key (mostly mandatory)
+=item * key
 
 A key used for token decryption (JWE) or token signature validation (JWS). The value depends on C<alg> token header value.
 
@@ -709,25 +709,25 @@ A key used for token decryption (JWE) or token signature validation (JWS). The v
  ECDH-ES+A192KW      private ECC key, see ECDH-ES
  ECDH-ES+A256KW      private ECC key, see ECDH-ES
 
-=item * keypass (optional, default: C<undef>)
+=item * keypass
 
-When 'key' parameter is an encrypted private RSA or ECC key this parameter may contain a password for private key decryption.
+When 'key' parameter is an encrypted private RSA or ECC key this optional parameter may contain a password for private key decryption.
 
-=item * allow_none (optional, default: C<0>)
+=item * allow_none
 
 C<1> - accept JWS tokens with C<none> 'alg' header value (which means that token has no signature), B<BEWARE: DANGEROUS, UNSECURE!!!>
 
-C<0> - do not allow JWS with C<none> 'alg' header value
+C<0> (default) - do not allow JWS with C<none> 'alg' header value
 
-=item * ignore_signature (optional, default: C<0>)
+=item * ignore_signature
 
 C<1> - do not check signature on JWS tokens, B<BEWARE: DANGEROUS, UNSECURE!!!>
 
-C<0> - check signature on JWS tokens
+C<0> (default) - check signature on JWS tokens
 
-=item * accepted_alg (optional, default: C<undef>)
+=item * accepted_alg
 
-C<undef> means accept all 'alg' algorithms except 'none' (for accepting 'none' use C<allow_none>)
+C<undef> (default) means accept all 'alg' algorithms except 'none' (for accepting 'none' use C<allow_none>)
 
 C<string> name of accepted 'alg' algorithm (only one)
 
@@ -741,9 +741,9 @@ C<Regexp> that has to match 'alg' algorithm name
  #or
  my $payload = decode_jwt(token=>$t, key=>$k, accepted_enc=>qr/^HS(256|384|512)$/);
 
-=item * accepted_enc (optional, default: C<undef>)
+=item * accepted_enc
 
-C<undef> means accept all 'enc' algorithms
+C<undef> (default) means accept all 'enc' algorithms
 
 C<string> name of accepted 'enc' algorithm (only one)
 
@@ -757,17 +757,17 @@ C<Regexp> that has to match 'enc' algorithm name
  #or
  my $payload = decode_jwt(token=>$t, key=>$k, accepted_enc=>qr/^A(128|192|256)GCM$/);
 
-=item * decode_payload (optional, default: C<undef>)
+=item * decode_payload
 
 C<0> - do not decode payload, return it as a raw string (octects).
 
 C<1> - decode payload from JSON string, return it as perl hash ref (or array ref) - decode_json failure means fatal error (croak).
 
-C<undef> - if possible decode payload from JSON string, if decode_json fails return payload as a raw string (octets).
+C<undef> (default) - if possible decode payload from JSON string, if decode_json fails return payload as a raw string (octets).
 
-=item * decode_header (optional, default: C<0>)
+=item * decode_header
 
-C<0> - do not return decoded header as a return value of decode_jwt()
+C<0> (default) - do not return decoded header as a return value of decode_jwt()
 
 C<1> - return decoded header as a return value of decode_jwt()
 
@@ -775,57 +775,65 @@ C<1> - return decoded header as a return value of decode_jwt()
  #or
  my ($header, $payload) = decode_jwt(token=>$t, key=>$k, decode_header=>1);
 
-=item * verify_iss (optional, default: C<undef>)
+=item * verify_iss
 
 C<CODE ref> - subroutine (with 'iss' claim value passed as argument) should return C<true> otherwise verification fails
 
 C<Regexp ref> - 'iss' claim value has to match given regexp otherwise verification fails
 
-=item * verify_aud (optional, default: C<undef>)
+C<undef> (default) - do not verify 'iss' claim
+
+=item * verify_aud
 
 C<CODE ref> - subroutine (with 'aud' claim value passed as argument) should return C<true> otherwise verification fails
 
 C<Regexp ref> - 'aud' claim value has to match given regexp otherwise verification fails
 
-=item * verify_sub (optional, default: C<undef>)
+C<undef> (default) - do not verify 'aud' claim
+
+=item * verify_sub
 
 C<CODE ref> - subroutine (with 'sub' claim value passed as argument) should return C<true> otherwise verification fails
 
 C<Regexp ref> - 'sub' claim value has to match given regexp otherwise verification fails
 
-=item * verify_jti (optional, default: C<undef>)
+C<undef> (default) - do not verify 'sub' claim
+
+=item * verify_jti
 
 C<CODE ref> - subroutine (with 'jti' claim value passed as argument) should return C<true> otherwise verification fails
 
 C<Regexp ref> - 'jti' claim value has to match given regexp otherwise verification fails
 
-=item * verify_iat (optional, default: C<undef>)
+C<undef> (default) - do not verify 'jti' claim
+
+=item * verify_iat
 
 C<0> - ignore 'iat' claim
 
 C<1> - require valid 'iat' claim
 
-C<undef> - 'iat' claim must be valid if present
+C<undef> (default) - 'iat' claim must be valid if present
 
-=item * verify_nbf (optional, default: C<undef>)
+=item * verify_nbf
 
 C<0> - ignore 'nbf' claim
 
 C<1> - require valid 'nbf' claim
 
-C<undef> - 'nbf' claim must be valid if present
+C<undef> (default) - 'nbf' claim must be valid if present
 
-=item * verify_exp (optional, default: C<undef>)
+=item * verify_exp
 
 C<0> - ignore 'exp' claim
 
 C<1> - require valid 'exp' claim
 
-C<undef> - 'exp' claim must be valid if present
+C<undef> (default) - 'exp' claim must be valid if present
 
-=item * leeway (optional, default: C<0>)
+=item * leeway
 
-Tolerance in seconds related to C<verify_exp>, C<verify_nbf>, C<verify_iat>.
+Tolerance in seconds related to C<verify_exp>, C<verify_nbf>, C<verify_iat>. Default is C<0>.
 
 =back
 
@@ -837,9 +845,9 @@ Named arguments:
 
 =over
 
-=item payload (mandatory)
+=item payload
 
-Value of this parameter can be a string/buffer or HASH ref or ARRAY ref
+Value of this mandatory parameter can be a string/buffer or HASH ref or ARRAY ref
 
  my $token = encode_jwt(payload=>"any raw data", key=>$k, alg=>'HS256');
  #or
@@ -849,7 +857,9 @@ Value of this parameter can be a string/buffer or HASH ref or ARRAY ref
 
 HASH refs and ARRAY refs payloads are serialized as JSON strings
 
-=item alg (mandatory)
+=item alg
+
+Mandatory 'alg' header value.
 
 Supported JWE 'alg' algorithms:
 
@@ -887,7 +897,9 @@ Supported JWS algorithms:
  ES384  ...  ECDSA + SHA384 signature
  ES512  ...  ECDSA + SHA512 signature
 
-=item enc (mandatory, for JWE only)
+=item enc
+
+Mandatory 'enc' header value.
 
 Supported 'enc' algorithms:
 
@@ -898,7 +910,7 @@ Supported 'enc' algorithms:
  A192CBC-HS384
  A256CBC-HS512
 
-=item key (mostly mandatory)
+=item key
 
 A key used for token encryption (JWE) or token signing (JWS). The value depends on C<alg> token header value.
 
@@ -944,56 +956,60 @@ A key used for token encryption (JWE) or token signing (JWS). The value depends
  ECDH-ES+A192KW      public ECC key, see ECDH-ES
  ECDH-ES+A256KW      public ECC key, see ECDH-ES
 
-=item keypass (optional, default: C<undef>)
+=item keypass
 
-When 'key' parameter is an encrypted private RSA or ECC key this parameter may contain a password for private key decryption.
+When 'key' parameter is an encrypted private RSA or ECC key this optional parameter may contain a password for private key decryption.
 
-=item allow_none (optional, default: C<0>)
+=item allow_none
 
 C<1> - allow JWS with C<none> 'alg' header value (which means that token has no signature), B<BEWARE: DANGEROUS, UNSECURE!!!>
 
-C<0> - do not allow JWS with C<none> 'alg' header value
+C<0> (default) - do not allow JWS with C<none> 'alg' header value
 
-=item extra_headers (optional, default: C<undef>)
+=item extra_headers
 
-This parameter may contain a HASH ref with items that will be added to JWT header.
+This optional parameter may contain a HASH ref with items that will be added to JWT header.
 
-=item zip (optional, default: C<undef>)
+=item zip
 
-Compression method, currently 'deflate' is the only one supported.
+Compression method, currently 'deflate' is the only one supported. C<undef> (default) means no compression.
 
  my $token = encode_jwt(payload=>$p, key=>$k, alg=>'HS256', zip=>'deflate');
  #or define compression level
  my $token = encode_jwt(payload=>$p, key=>$k, alg=>'HS256', zip=>['deflate', 9]);
 
-=item auto_iat (optional, default: C<0>)
+=item auto_iat
 
 C<1> - set 'iat' (Issued At) claim to current time (epoch seconds since 1970) at the moment of token encoding
 
-C<0> - do not set 'iat' claim
+C<0> (default) - do not set 'iat' claim
 
 NOTE: claims are part of the payload and can be used only if the payload is a HASH ref!
 
-=item relative_exp (optional, default: C<undef>)
+=item relative_exp
 
 Set 'exp' claim (Expiration Time) to current time + C<relative_exp> value (in seconds).
 
 NOTE: claims are part of the payload and can be used only if the payload is a HASH ref!
 
-=item relative_nbf (optional, default: C<undef>)
+=item relative_nbf
 
 Set 'nbf' claim (Not Before) to current time + C<relative_exp> value (in seconds).
 
 NOTE: claims are part of the payload and can be used only if the payload is a HASH ref!
 
-=item auto_typ (optional, default: C<0>)
+=item auto_typ
 
 C<1> - set 'typ' header to value C<JWS> for JWS tokens and C<JWE> for JWE tokens.
 
-C<0> - do not set 'typ' header
+C<0> (default) - do not set 'typ' header
 
 =back
 
 =head1 SEE ALSO
 
 L<Crypt::Cipher::AES>, L<Crypt::AuthEnc::GCM>, L<Crypt::PK::RSA>, L<Crypt::PK::ECC>, L<Crypt::KeyDerivation>, L<Crypt::KeyWrap>
+
+
+
+
